import setuptools

setuptools.setup(
    name="nanostream",
    version="0.1.0",
    author="Zachary Ernst",
    author_email="zac.ernst@gmail.com",
    description="Small-scale stream processing",
    url="https://github.com/zacernst/nanostream",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
